@@ -45,7 +45,7 @@
 #define BUFFER_LENGTH 512
 
 // Build issue on some systems (OSS 4.0)?
-#ifndef SOUND_PCM_WRITE_CHANNELS
+#ifdef SNDCTL_DSP_CHANNELS
   #define SOUND_PCM_WRITE_CHANNELS        SNDCTL_DSP_CHANNELS
 #endif
 
