@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307, USA
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
 #include "fluid_midi.h"
@@ -585,6 +585,16 @@ fluid_midi_file_read_event(fluid_midi_file *mf, fluid_track_t *track)
                     break;
                 }
                 mf->eot = 1;
+                evt = new_fluid_midi_event();
+                if (evt == NULL) {
+                    FLUID_LOG(FLUID_ERR, "Out of memory");
+                    result = FLUID_FAILED;
+                    break;
+                }
+                evt->dtime = mf->dtime;
+                evt->type = MIDI_EOT;
+                fluid_track_add_event(track, evt);
+                mf->dtime = 0;
                 break;
 
             case MIDI_SET_TEMPO:
@@ -1204,12 +1214,15 @@ fluid_track_send_events(fluid_track_t *track,
 
         track->ticks += event->dtime;
 
-        if (event->type != MIDI_SET_TEMPO) {
+        if (!player || event->type == MIDI_EOT) {
+        }
+        else if (event->type == MIDI_SET_TEMPO) {
+            fluid_player_set_midi_tempo(player, event->param1);
+        }
+        else {
             if (player->playback_callback)
                 player->playback_callback(player->playback_userdata, event);
-	}
-        else if (player)
-            fluid_player_set_midi_tempo(player, event->param1);
+        }
 
         fluid_track_next_event(track);
 
