@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307, USA
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
 
@@ -109,6 +109,12 @@ char* fluid_defsfont_sfont_get_name(fluid_sfont_t* sfont)
   return fluid_defsfont_get_name((fluid_defsfont_t*) sfont->data);
 }
 
+fluid_sample_t* fluid_defsfont_get_sample(fluid_defsfont_t* sfont, char *s)
+{
+  /* This function is here just to avoid an ABI/SONAME bump, see ticket #98. Should never be used. */
+  return NULL;
+}
+
 fluid_preset_t*
 fluid_defsfont_sfont_get_preset(fluid_sfont_t* sfont, unsigned int bank, unsigned int prenum)
 {
